
class CookPersistenceInterface:
    def __init__(self):
        pass

    def read_cook_count(self):
        pass

    def read_cook(self, cook_name):
        pass

    def save_cook(self, cook):
        pass

    def remove_cook(self, cook):
        pass

    def print_all(self):
        pass
